Package: multiModTest
Type: Package
Title: Information Assessment for Individual Modalities in Multimodal
        Regression Models
Version: 1.0
Authors@R: c(
    person("Wanting", "Jin", email = "jinwanting5@gmail.com", role = c("aut", "cre")),
    person("Quefeng", "Li", email = "quefeng@email.unc.edu", role = "aut")
    )
Description: Provides methods for quantifying the information gain contributed by individual 
	modalities in multimodal regression models. Information gain is measured using Expected 
	Relative Entropy (ERE) or pseudo-R² metrics, with corresponding p-values and confidence 
	intervals. Currently supports linear and logistic regression models with plans for 
	extension to additional Generalized Linear Models and Cox proportional hazard model.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: tidyverse, MASS, SIS, glmnet, ncvreg, MBESS, survival, dplyr
Depends: R (>= 3.6.0)
NeedsCompilation: no
Packaged: 2025-08-29 20:33:59 UTC; 10518
Author: Wanting Jin [aut, cre],
  Quefeng Li [aut]
Maintainer: Wanting Jin <jinwanting5@gmail.com>
LazyData: true
Repository: CRAN
Date/Publication: 2025-09-03 21:30:02 UTC
Built: R 4.6.0; ; 2026-04-30 20:52:52 UTC; unix
