# Generated by roxygen2: do not edit by hand

S3method(print,summary.mglm.test)
S3method(summary,mglm.test)
export(mglm.test)
import(stats)
importFrom(MASS,glm.nb)
importFrom(MASS,mvrnorm)
importFrom(MBESS,conf.limits.nc.chisq)
importFrom(SIS,SIS)
importFrom(dplyr,case_when)
importFrom(glmnet,cv.glmnet)
importFrom(glmnet,glmnet)
importFrom(ncvreg,cv.ncvreg)
importFrom(ncvreg,cv.ncvsurv)
importFrom(ncvreg,ncvreg)
importFrom(ncvreg,ncvsurv)
importFrom(stats,BIC)
importFrom(stats,sd)
importFrom(survival,Surv)
importFrom(survival,coxph)
importFrom(utils,capture.output)
