% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_simu.R
\docType{data}
\name{data_linear_model}
\alias{data_linear_model}
\title{Example Dataset}
\format{
A data object that contains
\describe{
  \item{\code{y}}{A vector of 200 observations of continuous outcomes.}
  \item{\code{X}}{A 200 \eqn{\times} 600 matrix containing all training data.}
  \item{\code{mod.idx}}{A list of modality indices.}
}
}
\usage{
data_linear_model
}
\description{
A toy dataset to demonstrate running this package on multimodal linear models.
}
\keyword{datasets}
