% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_simu.R
\docType{data}
\name{data_cox_model}
\alias{data_cox_model}
\title{Example Dataset}
\format{
A data object that contains
\describe{
  \item{\code{y}}{A 200 \eqn{\times} 2 matrix of survival outcomes, with columns
  \code{time} (the observed follow-up time) and \code{status} (the event
  indicator: 1 = event, 0 = censored). It may be passed directly to
  \code{\link{mglm.test}}, or converted with \code{\link[survival]{Surv}}.}
  \item{\code{X}}{A 200 \eqn{\times} 800 matrix containing all training data.}
  \item{\code{mod.idx}}{A list of modality indices: columns 1--400 form
  modality 1 and columns 401--800 form modality 2.}
}
}
\usage{
data_cox_model
}
\description{
A toy dataset to demonstrate running this package on multimodal Cox
proportional hazards models. Survival times follow a Cox model with
independent right censoring (about 27\% of the observations are censored).
}
\keyword{datasets}
