% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.mglm.test.R
\name{summary.mglm.test}
\alias{summary.mglm.test}
\alias{print.summary.mglm.test}
\title{Summary method for objects of class "mglm.test"}
\usage{
\method{summary}{mglm.test}(object, ...)

\method{print}{summary.mglm.test}(x, ...)
}
\arguments{
\item{object}{An \code{mglm.test} object.}

\item{...}{Additional arguments that could be passed to \code{summary.mglm.test}.}

\item{x}{A \code{summary.mglm.test} object.}
}
\value{
An object with S3 class \code{summary.mglm.test}. The class has its own print
method and contains the following list of elements.
\item{sum.ERE}{The summary table of point estimate and confidence interval
of ERE for each modality.}
\item{sum.R2}{The summary table of point estimate and confidence interval
of pseudo-\eqn{R^2} for each modality.}
\item{conf.level}{ Level of confidence intervals.}
\item{sel.mod}{ Index of the most informative modality.}
}
\description{
Summary method for objects of class "mglm.test"
}
